=== modified file 'config/autorun.sh'
--- config/autorun.sh	2009-06-30 18:09:07 +0000
+++ config/autorun.sh	2009-07-10 20:57:17 +0000
@@ -1,186 +1,99 @@
-#!/usr/bin/env bash
+#!/bin/sh
 # Taken from lighthttpd server (BSD). Thanks Jan!
 # Run this to generate all the initial makefiles, etc.
 
 die() { echo "$@"; exit 1; }
 
-# LIBTOOLIZE=${LIBTOOLIZE:-libtoolize}
+# --force means overwrite ltmain.sh script if it already exists 
 LIBTOOLIZE_FLAGS=" --automake --copy --force"
-# ACLOCAL=${ACLOCAL:-aclocal}
-ACLOCAL_FLAGS="-I m4"
-# AUTOHEADER=${AUTOHEADER:-autoheader}
-# AUTOMAKE=${AUTOMAKE:-automake}
 # --add-missing instructs automake to install missing auxiliary files
-# --copy tells it to make copies and not symlinks
+# and --force to overwrite them if they already exist
 AUTOMAKE_FLAGS="--add-missing --copy --force"
-# AUTOCONF=${AUTOCONF:-autoconf}
+ACLOCAL_FLAGS="-I m4"
 
 ARGV0=$0
 ARGS="$@"
 
-
 run() {
 	echo "$ARGV0: running \`$@' $ARGS"
 	$@ $ARGS
 }
 
-## jump out if one of the programs returns 'false'
-set -e
-
-RELEASE_DATE=`date +%Y.%m`
-RELEASE_DATE_NODOTS=`date +%Y%m`
-if test -d ".bzr" ; then
-  echo "Grabbing changelog and version information from bzr"
-  bzr log --short > ChangeLog || touch ChangeLog
-  BZR_REVNO=`bzr revno`
-  BZR_REVID=`bzr log -r-1 --show-ids | grep revision-id | awk '{print $2}' | head -1`
-  BZR_BRANCH=`bzr nick`
-else
-  touch ChangeLog
-  BZR_REVNO="0"
-  BZR_REVID="unknown"
-  BZR_BRANCH="bzr-export"
-fi
-RELEASE_VERSION="${RELEASE_DATE}.${BZR_REVNO}"
-RELEASE_ID="${RELEASE_DATE_NODOTS}${BZR_REVNO}"
-if test "x${BZR_BRANCH}" != "xdrizzle" ; then
-  RELEASE_COMMENT="${BZR_BRANCH}"
-else
-  RELEASE_COMMENT="trunk"
-fi
-
-if test -f m4/bzr_version.m4.in
-then
-  sed -e "s/@BZR_REVNO@/${BZR_REVNO}/" \
-      -e "s/@BZR_REVID@/${BZR_REVID}/" \
-      -e "s/@BZR_BRANCH@/${BZR_BRANCH}/" \
-      -e "s/@RELEASE_DATE@/${RELEASE_DATE}/" \
-      -e "s/@RELEASE_ID@/${RELEASE_ID}/" \
-      -e "s/@RELEASE_VERSION@/${RELEASE_VERSION}/" \
-      -e "s/@RELEASE_COMMENT@/${RELEASE_COMMENT}/" \
-    m4/bzr_version.m4.in > m4/bzr_version.m4.new
-  
-  if ! diff m4/bzr_version.m4.new m4/bzr_version.m4 >/dev/null 2>&1 ; then
-    mv m4/bzr_version.m4.new m4/bzr_version.m4
-  else
-    rm m4/bzr_version.m4.new
-  fi
-fi
-
-EGREP=`which egrep`
-if test "x$EGREP" != "x" -a -d po
-then
-  echo "# This file is auto-generated from configure. Do not edit directly" > po/POTFILES.in.in
-  # The grep -v 'drizzle-' is to exclude any distcheck leftovers
-  for f in `find . | grep -v 'drizzle-' | ${EGREP} '\.(cc|c|h|yy)$' | cut -c3- | sort`
+# Try to locate a program by using which, and verify that the file is an
+# executable
+locate_binary() {
+  for f in $@
   do
-    if grep gettext.h "$f" | grep include >/dev/null 2>&1
-    then
-      echo "$f" >> po/POTFILES.in.in
+    file=`which $f 2>/dev/null | grep -v '^no '`
+    if test -n "$file" -a -x "$file"; then
+      echo $file
+      return 0
     fi
   done
-  if ! diff po/POTFILES.in.in po/POTFILES.in >/dev/null 2>&1
-  then
-    mv po/POTFILES.in.in po/POTFILES.in
-  else
-    rm po/POTFILES.in.in
-  fi
-else
-  touch po/POTFILES.in
+
+  echo "" 
+  return 1
+}
+
+
+if test -f config/pre_hook.sh
+then
+  . config/pre_hook.sh
 fi
 
+# Try to detect the supported binaries if the user didn't
+# override that by pushing the environment variable
 if test x$LIBTOOLIZE = x; then
-  if test \! "x`which glibtoolize 2> /dev/null | grep -v '^no'`" = x; then
-    LIBTOOLIZE=glibtoolize
-  elif test \! "x`which libtoolize-2.2 2> /dev/null | grep -v '^no'`" = x; then
-    LIBTOOLIZE=libtoolize-2.2
-  elif test \! "x`which libtoolize-1.5 2> /dev/null | grep -v '^no'`" = x; then
-    LIBTOOLIZE=libtoolize-1.5
-  elif test \! "x`which libtoolize 2> /dev/null | grep -v '^no'`" = x; then
-    LIBTOOLIZE=libtoolize
-  elif test \! "x`which glibtoolize 2> /dev/null | grep -v '^no'`" = x; then
-    LIBTOOLIZE=glibtoolize
-  else
-    echo "libtoolize wasn't found, exiting"; exit 1
+  LIBTOOLIZE=`locate_binary glibtoolize libtoolize-1.5 libtoolize`
+  if test x$LIBTOOLIZE = x; then
+    die "Did not find a supported libtoolize"
   fi
 fi
 
 if test x$ACLOCAL = x; then
-  if test \! "x`which aclocal-1.10 2> /dev/null | grep -v '^no'`" = x; then
-    ACLOCAL=aclocal-1.10
-  elif test \! "x`which aclocal110 2> /dev/null | grep -v '^no'`" = x; then
-    ACLOCAL=aclocal110
-  elif test \! "x`which aclocal 2> /dev/null | grep -v '^no'`" = x; then
-    ACLOCAL=aclocal
-  else 
-    echo "automake 1.10.x (aclocal) wasn't found, exiting"; exit 1
+  ACLOCAL=`locate_binary aclocal-1.10 aclocal-1.9 aclocal19 aclocal`
+  if test x$ACLOCAL = x; then
+    die "Did not find a supported aclocal"
   fi
 fi
 
 if test x$AUTOMAKE = x; then
-  if test \! "x`which automake-1.10 2> /dev/null | grep -v '^no'`" = x; then
-    AUTOMAKE=automake-1.10
-  elif test \! "x`which automake110 2> /dev/null | grep -v '^no'`" = x; then
-    AUTOMAKE=automake110
-  elif test \! "x`which automake 2> /dev/null | grep -v '^no'`" = x; then
-    AUTOMAKE=automake
-  else 
-    echo "automake 1.10.x wasn't found, exiting"; exit 1
+  AUTOMAKE=`locate_binary automake-1.10 automake-1.9 automake19 automake`
+  if test x$AUTOMAKE = x; then
+    die "Did not find a supported automake"
   fi
 fi
 
-
-## macosx has autoconf-2.59 and autoconf-2.60
 if test x$AUTOCONF = x; then
-  if test \! "x`which autoconf-2.63 2> /dev/null | grep -v '^no'`" = x; then
-    AUTOCONF=autoconf-2.63
-  elif test \! "x`which autoconf263 2> /dev/null | grep -v '^no'`" = x; then
-    AUTOCONF=autoconf263
-  elif test \! "x`which autoconf-2.60 2> /dev/null | grep -v '^no'`" = x; then
-    AUTOCONF=autoconf-2.60
-  elif test \! "x`which autoconf260 2> /dev/null | grep -v '^no'`" = x; then
-    AUTOCONF=autoconf260
-  elif test \! "x`which autoconf-2.59 2> /dev/null | grep -v '^no'`" = x; then
-    AUTOCONF=autoconf-2.59
-  elif test \! "x`which autoconf259 2> /dev/null | grep -v '^no'`" = x; then
-    AUTOCONF=autoconf259
-  elif test \! "x`which autoconf 2> /dev/null | grep -v '^no'`" = x; then
-    AUTOCONF=autoconf
-  else 
-    echo "autoconf 2.59+ wasn't found, exiting"; exit 1
+  AUTOCONF=`locate_binary autoconf-2.59 autoconf259 autoconf`
+  if test x$AUTOCONF = x; then
+    die "Did not find a supported autoconf"
   fi
 fi
 
 if test x$AUTOHEADER = x; then
-  if test \! "x`which autoheader-2.63 2> /dev/null | grep -v '^no'`" = x; then
-    AUTOHEADER=autoheader-2.63
-  elif test \! "x`which autoheader263 2> /dev/null | grep -v '^no'`" = x; then
-    AUTOHEADER=autoheader263
-  elif test \! "x`which autoheader-2.60 2> /dev/null | grep -v '^no'`" = x; then
-    AUTOHEADER=autoheader-2.60
-  elif test \! "x`which autoheader260 2> /dev/null | grep -v '^no'`" = x; then
-    AUTOHEADER=autoheader260
-  elif test \! "x`which autoheader-2.59 2> /dev/null | grep -v '^no'`" = x; then
-    AUTOHEADER=autoheader-2.59
-  elif test \! "x`which autoheader259 2> /dev/null | grep -v '^no'`" = x; then
-    AUTOHEADER=autoheader259
-  elif test \! "x`which autoheader 2> /dev/null | grep -v '^no'`" = x; then
-    AUTOHEADER=autoheader
-  else 
-    echo "autoconf 2.59+ (autoheader) wasn't found, exiting"; exit 1
+  AUTOHEADER=`locate_binary autoheader-2.59 autoheader259 autoheader`
+  if test x$AUTOHEADER = x; then
+    die "Did not find a supported autoheader"
   fi
 fi
 
-
-# --force means overwrite ltmain.sh script if it already exists 
-run python config/register_plugins.py || die  "Can't execute register_plugins"
 run $LIBTOOLIZE $LIBTOOLIZE_FLAGS || die "Can't execute libtoolize"
-
 run $ACLOCAL $ACLOCAL_FLAGS || die "Can't execute aclocal"
 run $AUTOHEADER || die "Can't execute autoheader"
 run $AUTOMAKE $AUTOMAKE_FLAGS  || die "Can't execute automake"
 run $AUTOCONF || die "Can't execute autoconf"
-echo -n "Automade with: "
-$AUTOMAKE --version | head -1
-echo -n "Configured with: "
-$AUTOCONF --version | head -1
+
+if test -f config/post_hook.sh
+then
+  . config/post_hook.sh
+fi
+
+echo "---"
+echo "Configured with the following tools:"
+echo "  * `$LIBTOOLIZE --version | head -1`"
+echo "  * `$ACLOCAL --version | head -1`"
+echo "  * `$AUTOHEADER --version | head -1`"
+echo "  * `$AUTOMAKE --version | head -1`"
+echo "  * `$AUTOCONF --version | head -1`"
+echo "---"

=== added file 'config/pre_hook.sh'
--- config/pre_hook.sh	1970-01-01 00:00:00 +0000
+++ config/pre_hook.sh	2009-07-10 20:57:17 +0000
@@ -0,0 +1,66 @@
+#!/bin/sh
+# pre_hook.sh - Commands that we run before we run the autotools
+
+RELEASE_DATE=`date +%Y.%m`
+RELEASE_DATE_NODOTS=`date +%Y%m`
+if test -d ".bzr" ; then
+  echo "Grabbing changelog and version information from bzr"
+  bzr log --short > ChangeLog || touch ChangeLog
+  BZR_REVNO=`bzr revno`
+  BZR_REVID=`bzr log -r-1 --show-ids | grep revision-id | awk '{print $2}' | head -1`
+  BZR_BRANCH=`bzr nick`
+else
+  touch ChangeLog
+  BZR_REVNO="0"
+  BZR_REVID="unknown"
+  BZR_BRANCH="bzr-export"
+fi
+RELEASE_VERSION="${RELEASE_DATE}.${BZR_REVNO}"
+RELEASE_ID="${RELEASE_DATE_NODOTS}${BZR_REVNO}"
+if test "x${BZR_BRANCH}" != "xdrizzle" ; then
+  RELEASE_COMMENT="${BZR_BRANCH}"
+else
+  RELEASE_COMMENT="trunk"
+fi
+
+if test -f m4/bzr_version.m4.in
+then
+  sed -e "s/@BZR_REVNO@/${BZR_REVNO}/" \
+      -e "s/@BZR_REVID@/${BZR_REVID}/" \
+      -e "s/@BZR_BRANCH@/${BZR_BRANCH}/" \
+      -e "s/@RELEASE_DATE@/${RELEASE_DATE}/" \
+      -e "s/@RELEASE_ID@/${RELEASE_ID}/" \
+      -e "s/@RELEASE_VERSION@/${RELEASE_VERSION}/" \
+      -e "s/@RELEASE_COMMENT@/${RELEASE_COMMENT}/" \
+    m4/bzr_version.m4.in > m4/bzr_version.m4.new
+  
+  if ! diff m4/bzr_version.m4.new m4/bzr_version.m4 >/dev/null 2>&1 ; then
+    mv m4/bzr_version.m4.new m4/bzr_version.m4
+  else
+    rm m4/bzr_version.m4.new
+  fi
+fi
+
+EGREP=`which egrep`
+if test "x$EGREP" != "x" -a -d po
+then
+  echo "# This file is auto-generated from configure. Do not edit directly" > po/POTFILES.in.in
+  # The grep -v 'drizzle-' is to exclude any distcheck leftovers
+  for f in `find . | grep -v 'drizzle-' | ${EGREP} '\.(cc|c|h|yy)$' | cut -c3- | sort`
+  do
+    if grep gettext.h "$f" | grep include >/dev/null 2>&1
+    then
+      echo "$f" >> po/POTFILES.in.in
+    fi
+  done
+  if ! diff po/POTFILES.in.in po/POTFILES.in >/dev/null 2>&1
+  then
+    mv po/POTFILES.in.in po/POTFILES.in
+  else
+    rm po/POTFILES.in.in
+  fi
+else
+  touch po/POTFILES.in
+fi
+
+run python config/register_plugins.py || die  "Can't execute register_plugins"

=== modified file 'config/uncrustify.cfg'
--- config/uncrustify.cfg	2008-12-07 19:38:53 +0000
+++ config/uncrustify.cfg	2009-07-10 21:50:02 +0000
@@ -132,7 +132,7 @@
 nl_template_class=add
 nl_class_brace=add
 nl_class_init_args=add
-nl_func_type_name=add
+nl_func_type_name=remove
 nl_func_proto_type_name=remove
 nl_func_paren=remove
 nl_func_decl_start=remove

=== added file 'extra/clean_source.sh'
--- extra/clean_source.sh	1970-01-01 00:00:00 +0000
+++ extra/clean_source.sh	2009-07-10 21:50:02 +0000
@@ -0,0 +1,22 @@
+#!/bin/sh
+
+#  Copyright (C) 2009 Sun Microsystems, Inc
+#
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; version 2 of the License.
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  You should have received a copy of the GNU General Public License
+#  along with this program; if not, write to the Free Software
+#  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
+for file in `ack-grep -f | grep -v innobase | grep -v '\.pb\.'| grep -v bak-header | grep -v '^intl' | grep -v '^config' `; do
+	grep Copyright $file >/dev/null 2>&1 || echo "No copyright header in $file"
+	uncrustify -c ../config/uncrustify.cfg --replace $file
+done
+

=== modified file 'm4/pandora_64bit.m4'
--- m4/pandora_64bit.m4	2009-07-08 07:09:13 +0000
+++ m4/pandora_64bit.m4	2009-07-10 23:00:57 +0000
@@ -8,34 +8,45 @@
 dnl ---------------------------------------------------------------------------
 AC_DEFUN([PANDORA_64BIT],[
 
+  AC_ARG_ENABLE([64bit],[
+    AS_HELP_STRING([--disable-64bit],
+      [Build 64 bit binary @<:@default=on@:>@])],
+             [ac_enable_64bit="$enableval"],
+             [ac_enable_64bit="yes"])
+
   AC_CHECK_PROGS(ISAINFO, [isainfo], [no])
   AS_IF([test "x$ISAINFO" != "xno"],
         [isainfo_b=`${ISAINFO} -b`],
         [isainfo_b="x"])
 
-  AS_IF([test "$isainfo_b" != "x"],
-        [AC_ARG_ENABLE([64bit],
-             [AS_HELP_STRING([--disable-64bit],
-                [Build 64 bit binary @<:@default=on@:>@])],
-             [ac_enable_64bit="$enableval"],
-             [ac_enable_64bit="yes"])])
-
-  AS_IF([test "x$ac_enable_64bit" = "xyes"],[
-         if test "x$libdir" = "x\${exec_prefix}/lib" ; then
-           # The user hasn't overridden the default libdir, so we'll 
-           # the dir suffix to match solaris 32/64-bit policy
-           isainfo_k=`${ISAINFO} -k` 
-           libdir="${libdir}/${isainfo_k}"
-         fi
-         CPPFLAGS="-m64 ${CPPFLAGS}"
-         LDFLAGS="-m64 ${LDFLAGS}"
-         DTRACEFLAGS="${DTRACEFLAGS} -64"
-         if test "$target_cpu" = "sparc" -a "x$SUNCC" = "xyes"
-         then
-            AM_CFLAGS="-xmemalign=8s ${AM_CFLAGS}"
-            AM_CXXFLAGS="-xmemalign=8s ${AM_CXXFLAGS}"
-         fi
-       ],[DTRACEFLAGS="${DTRACEFLAGS} -32"])
+  AS_IF([test "$isainfo_b" != "x"],[
+
+    isainfo_k=`${ISAINFO} -k` 
+    DTRACEFLAGS="${DTRACEFLAGS} -${isainfo_k}"
+
+    AS_IF([test "x${ac_cv_env_CPPFLAGS_set}" = "x"],[
+      CPPFLAGS="-I/usr/local ${CPPFLAGS}"
+    ])
+
+    AS_IF([test "x${ac_cv_env_LDFLAGS_set}" = "x"],[
+      LDFLAGS="-L/usr/local/lib/${isainfo_k} ${LDFLAGS}"
+    ])
+
+    AS_IF([test "x$ac_enable_64bit" = "xyes"],[
+      AS_IF([test "x$libdir" = "x\${exec_prefix}/lib"],[
+       dnl The user hasn't overridden the default libdir, so we'll 
+       dnl the dir suffix to match solaris 32/64-bit policy
+       libdir="${libdir}/${isainfo_k}"
+      ])
+
+      CPPFLAGS="-m64 ${CPPFLAGS}"
+      LDFLAGS="-m64 ${LDFLAGS}"
+      AS_IF([test "$target_cpu" = "sparc" -a "x$SUNCC" = "xyes"],[
+        AM_CFLAGS="-xmemalign=8s ${AM_CFLAGS}"
+        AM_CXXFLAGS="-xmemalign=8s ${AM_CXXFLAGS}"
+      ])
+    ])
+  ])
 ])
 dnl ---------------------------------------------------------------------------
 dnl End Macro: PANDORA_64BIT

=== modified file 'm4/pandora_canonical.m4'
--- m4/pandora_canonical.m4	2009-07-09 18:51:11 +0000
+++ m4/pandora_canonical.m4	2009-07-13 17:40:54 +0000
@@ -4,7 +4,7 @@
 dnl with or without modifications, as long as this notice is preserved.
 
 dnl Which version of the canonical setup we're using
-AC_DEFUN([PANDORA_CANONICAL_VERSION],[0.9])
+AC_DEFUN([PANDORA_CANONICAL_VERSION],[0.10])
 
 AC_DEFUN([PANDORA_FORCE_DEPEND_TRACKING],[
   dnl Force dependency tracking on for Sun Studio builds

